﻿using System;
using System.IO;                      // Directory
using System.Text;
using System.Runtime.InteropServices; // DLL Import

// Filename : IniFile.cs
// Date     : 2024/3/14
//
// Copyright (C) 2024 Grove Design Service All rights reserved.

class IniFile
{
    // INIファイルへの保存と読み出し

    private String ini_file_folder;
    private String ini_file_path;

    [DllImport("KERNEL32.DLL")]
    public static extern uint GetPrivateProfileString(string lpAppName, string lpKeyName, string lpDefault, StringBuilder lpReturnedString, uint nSize, string lpFileName);

    [DllImport("KERNEL32.DLL")]
    public static extern uint GetPrivateProfileInt(string lpAppName, string lpKeyName, int nDefault, string lpFileName);

    [DllImport("kernel32.dll")]
    private static extern int WritePrivateProfileString(string lpApplicationName, string lpKeyName, string lpstring, string lpFileName);

    public IniFile(String iniFilename)
    {
        // C:\Users\%user%\AppData\Local 以下にフォルダを作ってiniファイルを保存する
        // C:\Program Files\以下のexeファイルの場所はインストーラでインストールすると書込み禁止になるので利用できない

        ini_file_folder = Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData) + "\\GroveDesignService";
        ini_file_path = ini_file_folder + "\\" + iniFilename + ".ini";

        // 保存するフォルダが無い場合には作っておく。ないとiniファイルは生成されない。

        if (Directory.Exists(ini_file_folder) == false)
        {
            Directory.CreateDirectory(ini_file_folder);
        }
    }

    /// iniファイル中のセクションのキーを指定して、文字列を返す
    public String getValueString(String section, String key)
    {
        StringBuilder sb = new StringBuilder(1024);

        GetPrivateProfileString(section, key, "", sb, Convert.ToUInt32(sb.Capacity), ini_file_path);

        return sb.ToString();
    }

    /// iniファイル中のセクションのキーを指定して、整数値を返す
    public int getValueInt(String section, String key)
    {
        return (int)GetPrivateProfileInt(section, key, 0, ini_file_path);
    }

    /// 指定したセクション、キーに数値を書き込む
    public void setValueInt(String section, String key, int val)
    {
        WritePrivateProfileString(section, key, val.ToString(), ini_file_path);
    }

    /// 指定したセクション、キーに文字列を書き込む
    public void setValueString(String section, String key, String val)
    {
        WritePrivateProfileString(section, key, val, ini_file_path);
    }
}

