﻿using System;
using System.IO;                      // FileStream
using System.Text;                    // UTF8Encoding
using System.Windows;
using System.Windows.Forms;           // FolderBrowserDialog

// Filename : RawFile.cs
// Date     : 2024/3/14
//
// Copyright (C) 2024 Grove Design Service All rights reserved.

namespace EBViewer
{
    public partial class MainWindow : Window
    {
        FileStream rawfs;
        private bool bSaveToRaw = false;

        private void btn_saveFolder_Click(object sender, RoutedEventArgs e)
        {
            FolderBrowserDialog dlg = new FolderBrowserDialog();

            dlg.Description = "RAWファイルを保存するフォルダを指定して下さい";
            dlg.SelectedPath = tb_saveFolder.Text;

            if (dlg.ShowDialog() == System.Windows.Forms.DialogResult.OK)
            {
                tb_saveFolder.Text = dlg.SelectedPath;

                this.tb_saveFolder.Select(this.tb_saveFolder.Text.Length, 0);
            }
        }

        private static void AddText(FileStream fs, string s)
        {
            byte[] info = new UTF8Encoding(true).GetBytes(s);
            fs.Write(info, 0, info.Length);
        }
        private void createRawFile()
        {
            // スレッドから参照するため、チェックボックスを変数に反映しておく

            bSaveToRaw = (cb_saveToRaw.IsChecked == true) ? true : false;

            if (!bSaveToRaw) return;

            String folderName;

            if (tb_saveFolder.Text.Length == 0)
            {
                // そうでない場合には、マイドキュメント以下に保存する
                folderName = Environment.GetFolderPath(Environment.SpecialFolder.MyDocuments);
            }
            else
            {
                folderName = tb_saveFolder.Text + "\\";
            }

            DateTime dt = DateTime.Now;

            String filename = dt.ToString("MMdd-HHmm") + ".raw";

            int i = 1;

            while (File.Exists(folderName + filename))
            {
                filename = dt.ToString("MMdd-HHmm") + String.Format("_{0}.raw", i++);
            }

            tb_saveFileName.Text = filename;

            // ヘッダ情報を書き出す

            rawfs = new FileStream(folderName + filename, FileMode.Create);

            AddText(rawfs, "% camera_integrator_name " + makerStr + "\n");
            //          AddText(fs, "% date 2024 - 01 - 15 04:16:08\n");
            AddText(rawfs, "% date " + dt.ToString("yyyy-MM-dd HH:mm:ss") + "\n");
            AddText(rawfs, "% evt 3.0\n");
            AddText(rawfs, "% format EVT3; height = 480; width = 640\n");
            AddText(rawfs, "% generation 3.1\n");
            AddText(rawfs, "% geometry 640x480\n");
            AddText(rawfs, "% integrator_name " + makerStr + "\n");
            AddText(rawfs, "% plugin_integrator_name GroveDesignService\n");
            AddText(rawfs, "% plugin_name evc.dll\n");
            AddText(rawfs, "% sensor_generation 3.1\n");
            AddText(rawfs, "% serial_number " + serialNumberStr + "\n");
            AddText(rawfs, "% system_ID 40\n");
            AddText(rawfs, "% end\n");
        }

        private void writeRawFile(byte[] data)
        {
            try
            {
                if (bSaveToRaw && rawfs.CanWrite)
                {
                    rawfs.Write(data, 0, data.Length);
                }
            }
            catch (Exception e)
            {
                rawfs.Close();
            }
        }

        private void closeRawFile()
        {
            if (bSaveToRaw)
            {
                rawfs.Close();
            }
        }
    }

}
